bit_len

Function bit_len 

pub fn bit_len(base: u8, integer: &str) -> Option<usize>
Available on crate feature big only.
Returns the minimum binary bits necessary to represent the given integer in the given base.

This is known as the bit length function (m).

The base must be between 2 and 36, inclusive. Digits 10-35 are represented by a-z or A-Z

Examples

use numera::all::bit_len;

assert_eq![bit_len(10, "255"), Some(8)];
assert_eq![bit_len(16, "FFFFFFFFFFFF"), Some(48)];