NonNegativeInteger32

Struct NonNegativeInteger32 

pub struct NonNegativeInteger32(pub u32);
A 32-bit non-negative integer number, from the set $\Z^*$ ($\N _0$), also known as Nnz32.

The range of valid numeric values is $\lbrack0 \dots$ u32::MAX$\rbrack$.

It is equivalent to the u32 primitive.

Also known as a natural number, you can also use the alias Natural32.

Tuple Fields

0: u32

Implementations

Source

impl NonNegativeInteger32

Methods for all integers

pub const fn is_even(&self) -> bool

Returns true if this integer is even.

pub const fn is_odd(&self) -> bool

Returns true if this integer is odd.

pub const fn is_multiple_of(&self, other: &Self) -> bool

Returns true if this integer is a multiple of the other.

pub const fn is_divisor_of(&self, other: &Self) -> bool

Returns true if this integer is a divisor of the other.

pub const fn is_coprime(&self, other: &Self) -> bool

Returns true if self and other are relative primes, which means they have only 1 as their only common divisor.

Notation

$a \perp b$.

pub const fn digits(&self) -> usize

Returns the number of digits in base 10.

Source

impl NonNegativeInteger32

Methods for non-negative integers

pub fn is_prime(&self) -> Option<bool>

Returns Some(true) if this integer is prime, Some(false) if it’s not prime, or None if it can not be determined.

Returns None if this integer can’t be represented as a usize, or as a u32 in no-std.

pub const fn gcd(&self, other: &Self) -> Self

Calculates the Greatest Common Divisor of this integer and other.

pub const fn lcm(&self, other: &Self) -> Self

Calculates the Lowest Common Multiple of this integer and other.

Source

impl NonNegativeInteger32

pub const fn new(value: u32) -> Self

Returns a new NonNegativeInteger32.

Source

impl NonNegativeInteger32

Methods for resizing

pub fn as_larger(&self) -> NonNegativeInteger64

Returns the current number as the next larger bit-size.

This method is not implemented for the largest available bit-size.

pub fn as_larger_or_same(&self) -> NonNegativeInteger64

Returns the current number as the next larger bit-size, or the same if there’s no larger one available.

pub fn try_as_larger(&self) -> NumeraResult<NonNegativeInteger64>

Tries to return the current number as the next larger bit-size.

Errors

If there’s no larger bit-size available.

pub fn as_smaller_or_same(&self) -> NonNegativeIntegers

Available on crate feature try_from only.

Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.

pub fn try_as_smaller(&self) -> NumeraResult<NonNegativeInteger16>

Available on crate feature try_from only.

Tries to return the current number as the next smaller bit-size.

Errors

If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.