pub struct NonZeroInteger16(pub NonZeroI16);Expand description
A 16-bit non-zero integer number, from the set $\Z \setminus 0$,
also known as N0z16.
The range of valid numeric values is $\lbrack$i16::MIN $\dots -1, 1 \dots$ i16::MAX$\rbrack$.
It is equivalent to the NonZeroI16 primitive.
Tuple Fields
0: NonZeroI16Implementations
Sourceimpl NonZeroInteger16
Methods for all integers
impl NonZeroInteger16
Methods for all integers
Sourcepub const fn is_multiple_of(&self, other: &Self) -> bool
pub const fn is_multiple_of(&self, other: &Self) -> bool
Returns true if this integer is a multiple of the other.
Sourcepub const fn is_divisor_of(&self, other: &Self) -> bool
pub const fn is_divisor_of(&self, other: &Self) -> bool
Returns true if this integer is a divisor of the other.
Sourcepub const fn is_coprime(&self, other: &Self) -> bool
pub const fn is_coprime(&self, other: &Self) -> bool
Returns true if self and other are relative primes,
which means they have only 1 as their only common divisor.
Notation
$a \perp b$.
Sourceimpl NonZeroInteger16
Methods for non-negative integers
impl NonZeroInteger16
Methods for non-negative integers
Sourceimpl NonZeroInteger16
Integer addition
impl NonZeroInteger16
Integer addition
Sourcepub const fn basic_add(self, rhs: NonZeroInteger16) -> NonZeroInteger16
pub const fn basic_add(self, rhs: NonZeroInteger16) -> NonZeroInteger16
Sourcepub const fn checked_add(
self,
rhs: NonZeroInteger16,
) -> Option<NonZeroInteger16>
pub const fn checked_add( self, rhs: NonZeroInteger16, ) -> Option<NonZeroInteger16>
Checked addition.
Returns None if the result is 0, or it overflows.
Sourcepub const fn checked_saturating_add(
self,
rhs: NonZeroInteger16,
) -> Option<NonZeroInteger16>
pub const fn checked_saturating_add( self, rhs: NonZeroInteger16, ) -> Option<NonZeroInteger16>
Saturating addition.
Computes self + rhs, saturating at the numeric bounds instead of overflowing.
Panics
If the addition results in 0.
Sourcepub const fn checked_wrapping_add(
self,
rhs: NonZeroInteger16,
) -> Option<NonZeroInteger16>
pub const fn checked_wrapping_add( self, rhs: NonZeroInteger16, ) -> Option<NonZeroInteger16>
Wrapping (modular) addition.
Computes self + rhs, wrapping around at the boundary of the type.
Sourcepub const fn overflowing_add(
self,
rhs: NonZeroInteger16,
) -> (Option<NonZeroInteger16>, bool)
pub const fn overflowing_add( self, rhs: NonZeroInteger16, ) -> (Option<NonZeroInteger16>, bool)
Overflowing addition.
Returns a tuple of the addition along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourceimpl NonZeroInteger16
impl NonZeroInteger16
Sourcepub const fn new(value: i16) -> NumeraResult<Self>
pub const fn new(value: i16) -> NumeraResult<Self>
Sourcepub const unsafe fn new_unchecked(value: i16) -> Self
Available on crate feature not(safe) only.
pub const unsafe fn new_unchecked(value: i16) -> Self
not(safe) only.Sourceimpl NonZeroInteger16
Methods for resizing
impl NonZeroInteger16
Methods for resizing
Sourcepub fn as_larger(&self) -> NonZeroInteger32
pub fn as_larger(&self) -> NonZeroInteger32
Returns the current number as the next larger bit-size.
This method is not implemented for the largest available bit-size.
Sourcepub fn as_larger_or_same(&self) -> NonZeroInteger32
pub fn as_larger_or_same(&self) -> NonZeroInteger32
Returns the current number as the next larger bit-size, or the same if there’s no larger one available.
Sourcepub fn try_as_larger(&self) -> NumeraResult<NonZeroInteger32>
pub fn try_as_larger(&self) -> NumeraResult<NonZeroInteger32>
Tries to return the current number as the next larger bit-size.
Errors
If there’s no larger bit-size available.
Sourcepub fn as_smaller_or_same(&self) -> NonZeroIntegers
Available on crate feature try_from only.
pub fn as_smaller_or_same(&self) -> NonZeroIntegers
try_from only.Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.
Sourcepub fn try_as_smaller(&self) -> NumeraResult<NonZeroInteger8>
Available on crate feature try_from only.
pub fn try_as_smaller(&self) -> NumeraResult<NonZeroInteger8>
try_from only.Tries to return the current number as the next smaller bit-size.
Errors
If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.