AllNumbers

Enum AllNumbers 

#[non_exhaustive]
pub enum AllNumbers<N: Number> { Integer(AllIntegers), Rational(AllRationals), Any(N), }
The family of any kind of number, also known as AllN.

Notes

Note that it wont have several specific traits implemented, like for example Zero or NonZero, since they are mutually exclusive, and don’t apply to all cases.

The Numbers alias is more convenient to use unless you need to refer to custom numbers via the Any variant.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Integer(AllIntegers)



Rational(AllRationals)



Any(N)

Any other kind of number.