NonPositiveInteger16

Struct NonPositiveInteger16 

pub struct NonPositiveInteger16(pub u16);
A 16-bit non-positive integer number, from the set $\Z^- \cup {0}$, also known as Npz16.

The range of valid numeric values is $\lbrack$$-$u16::MAX $\dots0\rbrack$.

Please note that the given value will be interpreted as negative.

Tuple Fields

0: u16

Implementations

Source

impl NonPositiveInteger16

Methods for all integers

pub const fn is_even(&self) -> bool

Returns true if this integer is even.

pub const fn is_odd(&self) -> bool

Returns true if this integer is odd.

pub const fn is_multiple_of(&self, other: &Self) -> bool

Returns true if this integer is a multiple of the other.

pub const fn is_divisor_of(&self, other: &Self) -> bool

Returns true if this integer is a divisor of the other.

pub const fn digits(&self) -> usize

Returns the number of digits in base 10.

Source

impl NonPositiveInteger16

pub const fn new_neg(value: u16) -> Self

Returns a new NonPositiveInteger16.

Please note that the value will be interpreted as negative.

Source

impl NonPositiveInteger16

Methods for resizing

pub fn as_larger(&self) -> NonPositiveInteger32

Returns the current number as the next larger bit-size.

This method is not implemented for the largest available bit-size.

pub fn as_larger_or_same(&self) -> NonPositiveInteger32

Returns the current number as the next larger bit-size, or the same if there’s no larger one available.

pub fn try_as_larger(&self) -> NumeraResult<NonPositiveInteger32>

Tries to return the current number as the next larger bit-size.

Errors

If there’s no larger bit-size available.

pub fn as_smaller_or_same(&self) -> NonPositiveIntegers

Available on crate feature try_from only.

Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.

pub fn try_as_smaller(&self) -> NumeraResult<NonPositiveInteger8>

Available on crate feature try_from only.

Tries to return the current number as the next smaller bit-size.

Errors

If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.