IntegerBig

Struct IntegerBig 

pub struct IntegerBig(pub IBig);
Available on crate feature big only.
A big integer number, from the set $\Z$, also known as ZBig.

Tuple Fields

0: IBig

Implementations

Source

impl IntegerBig

Methods for all integers

pub fn is_even(&self) -> bool

Available on crate feature dashu-int only.

Returns true if this integer is even.

pub fn is_odd(&self) -> bool

Available on crate feature dashu-int only.

Returns true if this integer is odd.

pub fn is_multiple_of(&self, other: &Self) -> bool

Available on crate feature dashu-int only.

Returns true if this integer is a multiple of the other.

pub fn is_divisor_of(&self, other: &Self) -> bool

Available on crate feature dashu-int only.

Returns true if this integer is a divisor of the other.

pub fn is_coprime(&self, other: &Self) -> bool

Available on crate feature dashu-int only.

Returns true if self and other are relative primes, which means they have only 1 as their only common divisor.

Notation

$a \perp b$.

pub fn digits(&self) -> usize

Available on crate feature dashu-int only.

Returns the number of digits in base 10.

Source

impl IntegerBig

Methods for non-negative integers

pub fn is_prime(&self) -> Option<bool>

Available on crate feature dashu-int only.

Returns Some(true) if this integer is prime, Some(false) if it’s not prime, or None if it can not be determined.

Returns None if this integer can’t be represented as a usize.

pub fn gcd(&self, other: &Self) -> Self

Available on crate feature dashu-int only.

Calculates the Greatest Common Divisor of this integer and other.

pub fn lcm(&self, other: &Self) -> Self

Available on crate feature dashu-int only.

Calculates the Lowest Common Multiple of this integer and other.

Source

impl IntegerBig

pub fn pow(&self, exp: usize) -> IntegerBig

Available on crate feature dashu-int only.

Raises self to the power of exp.

Source

impl IntegerBig

pub fn new(value: i128) -> IntegerBig

Available on crate feature dashu-int only.

Returns a new IntegerBig.

pub fn from_string(value: &str) -> NumeraResult<IntegerBig>

Available on crate feature dashu-int only.

Returns a new IntegerBig from a string in base 10.

Errors

If the number is unparseable.

pub fn from_str_with_base(value: &str, base: u32) -> NumeraResult<IntegerBig>

Available on crate feature dashu-int only.

Returns a new IntegerBig from a string in the given base, which must be between 2 and 36, inclusive.

value may contain an optional + prefix. Digits 10-35 are represented by a-z or A-Z.

Panics

If base is <2 or >36.

Errors

If the number is unparseable.