pub struct NonPositiveInteger8(pub u8);Expand description
Tuple Fields
0: u8Implementations
Sourceimpl NonPositiveInteger8
Methods for all integers
impl NonPositiveInteger8
Methods for all integers
Sourcepub const fn is_multiple_of(&self, other: &Self) -> bool
pub const fn is_multiple_of(&self, other: &Self) -> bool
Returns true if this integer is a multiple of the other.
Sourcepub const fn is_divisor_of(&self, other: &Self) -> bool
pub const fn is_divisor_of(&self, other: &Self) -> bool
Returns true if this integer is a divisor of the other.
Sourceimpl NonPositiveInteger8
Methods for resizing
impl NonPositiveInteger8
Methods for resizing
Sourcepub fn as_larger(&self) -> NonPositiveInteger16
pub fn as_larger(&self) -> NonPositiveInteger16
Returns the current number as the next larger bit-size.
This method is not implemented for the largest available bit-size.
Sourcepub fn as_larger_or_same(&self) -> NonPositiveInteger16
pub fn as_larger_or_same(&self) -> NonPositiveInteger16
Returns the current number as the next larger bit-size, or the same if there’s no larger one available.
Sourcepub fn try_as_larger(&self) -> NumeraResult<NonPositiveInteger16>
pub fn try_as_larger(&self) -> NumeraResult<NonPositiveInteger16>
Tries to return the current number as the next larger bit-size.
Errors
If there’s no larger bit-size available.
Sourcepub fn as_smaller_or_same(&self) -> NonPositiveIntegers
Available on crate feature try_from only.
pub fn as_smaller_or_same(&self) -> NonPositiveIntegers
try_from only.Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.
Sourcepub fn try_as_smaller(&self) -> NumeraResult<NonPositiveInteger8>
Available on crate feature try_from only.
pub fn try_as_smaller(&self) -> NumeraResult<NonPositiveInteger8>
try_from only.Tries to return the current number as the next smaller bit-size.
Errors
If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.