NonZeroInteger128

Struct NonZeroInteger128 

pub struct NonZeroInteger128(pub NonZeroI128);
A 128-bit non-zero integer number, from the set $\Z \setminus 0$, also known as N0z128.

The range of valid numeric values is $\lbrack$i128::MIN $\dots -1, 1 \dots$ i128::MAX$\rbrack$.

It is equivalent to the NonZeroI128 primitive.

Tuple Fields

0: NonZeroI128

Implementations

Source

impl NonZeroInteger128

Methods for all integers

pub const fn is_even(&self) -> bool

Returns true if this integer is even.

pub const fn is_odd(&self) -> bool

Returns true if this integer is odd.

pub const fn is_multiple_of(&self, other: &Self) -> bool

Returns true if this integer is a multiple of the other.

pub const fn is_divisor_of(&self, other: &Self) -> bool

Returns true if this integer is a divisor of the other.

pub const fn is_coprime(&self, other: &Self) -> bool

Returns true if self and other are relative primes, which means they have only 1 as their only common divisor.

Notation

$a \perp b$.

pub const fn digits(&self) -> usize

Returns the number of digits in base 10.

Source

impl NonZeroInteger128

Methods for non-negative integers

pub fn is_prime(&self) -> Option<bool>

Returns Some(true) if this integer is prime, Some(false) if it’s not prime, or None if it can not be determined.

Returns None if this integer can’t be represented as a usize, or as a u32 in no-std.

pub const fn gcd(&self, other: &Self) -> Self

Calculates the Greatest Common Divisor of this integer and other.

pub const fn lcm(&self, other: &Self) -> Self

Calculates the Lowest Common Multiple of this integer and other.

Source

impl NonZeroInteger128

Integer addition

pub const fn basic_add(self, rhs: NonZeroInteger128) -> NonZeroInteger128

Integer addition.

Panics

If the addition results in 0, or overflows.

pub const fn checked_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>

Checked addition.

Returns None if the result is 0, or it overflows.

pub const fn checked_saturating_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>

Saturating addition. Computes self + rhs, saturating at the numeric bounds instead of overflowing.

Panics

If the addition results in 0.

pub const fn checked_wrapping_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>

Wrapping (modular) addition. Computes self + rhs, wrapping around at the boundary of the type.

pub const fn overflowing_add( self, rhs: NonZeroInteger128, ) -> (Option<NonZeroInteger128>, bool)

Overflowing addition.

Returns a tuple of the addition along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.

Source

impl NonZeroInteger128

pub const fn new(value: i128) -> NumeraResult<Self>

Returns a new NonZeroInteger128.

Errors

If the given value equals 0.

pub const unsafe fn new_unchecked(value: i128) -> Self

Available on crate feature not(safe) only.

Returns a new NonZeroInteger128.

Safety

The given value must not be 0.

Panics

Panics in debug if the given value is 0.

Source

impl NonZeroInteger128

Methods for resizing

pub fn as_larger_or_same(&self) -> NonZeroInteger128

Returns the current number as the next larger bit-size, or the same if there’s no larger one available.

pub fn try_as_larger(&self) -> NumeraResult<NonZeroInteger128>

Tries to return the current number as the next larger bit-size.

Errors

If there’s no larger bit-size available.

pub fn as_smaller_or_same(&self) -> NonZeroIntegers

Available on crate feature try_from only.

Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.

pub fn try_as_smaller(&self) -> NumeraResult<NonZeroInteger64>

Available on crate feature try_from only.

Tries to return the current number as the next smaller bit-size.

Errors

If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.