Prime16

Struct Prime16 

pub struct Prime16(/* private fields */);
A 16-bit prime number, from the set $\Bbb{P}$, also known as P16.

Can represent the first 6,542 prime numbers.

Implementations

Source

impl Prime16

pub fn new(value: u16) -> NumeraResult<Self>

Returns a new Prime16.

Errors

If the given value is not a prime number.

pub const fn new_nth(nth: u16) -> NumeraResult<Self>

Returns the nth prime number.

Errors

If nth is >= 6,542.

Examples
use numera::all::*;

assert_eq![Prime16::MIN, Prime16::new_nth(0)?];
assert_eq![Prime16::from(Prime8::MAX), Prime16::new_nth(53)?];
assert_eq![Prime16::MAX, Prime16::new_nth(6_541)?];
assert![Prime16::new_nth(6_542).is_err()];
pub unsafe fn new_unchecked(value: u16) -> Self

Available on crate feature not(safe) only.

Returns a new Prime16.

Safety

The given value must be a prime number.

Panics

Panics in debug if the given value is not a prime number.

pub fn pi(&self) -> usize

Returns the number of primes upto and including the current one.

Notation

$\pi(x)$

Example
use numera::all::{Numbers, Prime16};

assert_eq![1, Prime16::new(2)?.pi()];
assert_eq![54, Prime16::new(251)?.pi()];
assert_eq![55, Prime16::new(257)?.pi()];
assert_eq![6_542, Prime16::new(65_521)?.pi()];