#[non_exhaustive]pub enum RationalErrors {
ZeroDenominator,
NumeratorOverflow,
NumeratorUnderflow,
DenominatorOverflow,
DenominatorUnderflow,
}Expand description
Errors related to rationals.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroDenominator
Invalid value 0 in the denominator.
NumeratorOverflow
The value is too large to store in the current representation of the numerator.
NumeratorUnderflow
The value is too small to store in the current representation of the numerator
DenominatorOverflow
The value is too large to store in the current representation of the denominator.
DenominatorUnderflow
The value is too small to store in the current representation of the denominator