pub struct IntegerBig(pub IBig);Available on crate feature
big only.Expand description
A big integer number, from the set $\Z$,
also known as ZBig.
Tuple Fields
0: IBigImplementations
Sourceimpl IntegerBig
Methods for all integers
impl IntegerBig
Methods for all integers
Sourcepub fn is_even(&self) -> bool
Available on crate feature dashu-int only.
pub fn is_even(&self) -> bool
dashu-int only.Returns true if this integer is even.
Sourcepub fn is_odd(&self) -> bool
Available on crate feature dashu-int only.
pub fn is_odd(&self) -> bool
dashu-int only.Returns true if this integer is odd.
Sourcepub fn is_multiple_of(&self, other: &Self) -> bool
Available on crate feature dashu-int only.
pub fn is_multiple_of(&self, other: &Self) -> bool
dashu-int only.Returns true if this integer is a multiple of the other.
Sourcepub fn is_divisor_of(&self, other: &Self) -> bool
Available on crate feature dashu-int only.
pub fn is_divisor_of(&self, other: &Self) -> bool
dashu-int only.Returns true if this integer is a divisor of the other.
Sourcepub fn is_coprime(&self, other: &Self) -> bool
Available on crate feature dashu-int only.
pub fn is_coprime(&self, other: &Self) -> bool
dashu-int only.Returns true if self and other are relative primes,
which means they have only 1 as their only common divisor.
Notation
$a \perp b$.
Sourceimpl IntegerBig
Methods for non-negative integers
impl IntegerBig
Methods for non-negative integers
Sourcepub fn is_prime(&self) -> Option<bool>
Available on crate feature dashu-int only.
pub fn is_prime(&self) -> Option<bool>
dashu-int only.Returns Some(true) if this integer is prime, Some(false) if it’s not
prime, or None if it can not be determined.
Returns None if this integer can’t be represented as a usize.
Sourceimpl IntegerBig
impl IntegerBig
Sourcepub fn pow(&self, exp: usize) -> IntegerBig
Available on crate feature dashu-int only.
pub fn pow(&self, exp: usize) -> IntegerBig
dashu-int only.Raises self to the power of exp.
Sourceimpl IntegerBig
impl IntegerBig
Sourcepub fn new(value: i128) -> IntegerBig
Available on crate feature dashu-int only.
pub fn new(value: i128) -> IntegerBig
dashu-int only.Returns a new IntegerBig.
Sourcepub fn from_string(value: &str) -> NumeraResult<IntegerBig>
Available on crate feature dashu-int only.
pub fn from_string(value: &str) -> NumeraResult<IntegerBig>
dashu-int only.Sourcepub fn from_str_with_base(value: &str, base: u32) -> NumeraResult<IntegerBig>
Available on crate feature dashu-int only.
pub fn from_str_with_base(value: &str, base: u32) -> NumeraResult<IntegerBig>
dashu-int only.Trait Implementations
Sourceimpl Add for IntegerBig
Available on crate feature dashu-int only.
impl Add for IntegerBig
Available on crate feature
dashu-int only.Sourcefn add(self, rhs: IntegerBig) -> Self::Output
fn add(self, rhs: IntegerBig) -> Self::Output
Performs the + operation.
Sourcetype Output = IntegerBig
type Output = IntegerBig
The resulting type after applying the
+ operator.Sourceimpl AddAssign for IntegerBig
Available on crate feature dashu-int only.
impl AddAssign for IntegerBig
Available on crate feature
dashu-int only.Sourcefn add_assign(&mut self, rhs: IntegerBig)
fn add_assign(&mut self, rhs: IntegerBig)
Performs the -= operation.
Sourceimpl Bound for IntegerBig
Available on crate feature dashu-int only.
impl Bound for IntegerBig
Available on crate feature
dashu-int only.Sourcefn is_lower_bounded(&self) -> bool
fn is_lower_bounded(&self) -> bool
Returns true if the number is lower bounded.
Sourcefn is_upper_bounded(&self) -> bool
fn is_upper_bounded(&self) -> bool
Returns true if the number is upper bounded.
Sourcefn lower_bound(&self) -> Option<Self>
fn lower_bound(&self) -> Option<Self>
Returns the lower bound, if any.
Sourcefn upper_bound(&self) -> Option<Self>
fn upper_bound(&self) -> Option<Self>
Returns the upper bound, if any.
Sourceimpl Clone for IntegerBig
Available on crate feature dashu-int only.
impl Clone for IntegerBig
Available on crate feature
dashu-int only.Sourcefn clone(&self) -> IntegerBig
fn clone(&self) -> IntegerBig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstNegOne for IntegerBig
Available on crate feature dashu-int only.
impl ConstNegOne for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl ConstOne for IntegerBig
Available on crate feature dashu-int only.
impl ConstOne for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl ConstZero for IntegerBig
Available on crate feature dashu-int only.
impl ConstZero for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Count for IntegerBig
Available on crate feature dashu-int only.
impl Count for IntegerBig
Available on crate feature
dashu-int only.Sourcefn is_countable(&self) -> bool
fn is_countable(&self) -> bool
Returns
true if the number is countable.Sourcefn is_uncountable(&self) -> bool
fn is_uncountable(&self) -> bool
Returns
false if the number is countable.Sourceimpl Countable for IntegerBig
Available on crate feature dashu-int only.
impl Countable for IntegerBig
Available on crate feature
dashu-int only.Sourcefn next(&self) -> NumeraResult<Self>
fn next(&self) -> NumeraResult<Self>
Returns the next countable value. Read more
Sourcefn previous(&self) -> NumeraResult<Self>
fn previous(&self) -> NumeraResult<Self>
Returns the previous countable value. Read more
Sourceimpl Debug for IntegerBig
Available on crate feature dashu-int only.
impl Debug for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Display for IntegerBig
Available on crate feature dashu-int only.
impl Display for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Integer128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Integer128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &Integer128) -> Self
fn from(f: &Integer128) -> Self
Converts to this type from the input type.
Sourceimpl From<&Integer16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Integer16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Integer32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Integer32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Integer64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Integer64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Integer8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Integer8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&NegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NegativeInteger128) -> Self
fn from(f: &NegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NegativeInteger16) -> Self
fn from(f: &NegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NegativeInteger32) -> Self
fn from(f: &NegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NegativeInteger64) -> Self
fn from(f: &NegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NegativeInteger8) -> Self
fn from(f: &NegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonNegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonNegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonNegativeInteger128) -> Self
fn from(f: &NonNegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonNegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonNegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonNegativeInteger16) -> Self
fn from(f: &NonNegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonNegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonNegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonNegativeInteger32) -> Self
fn from(f: &NonNegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonNegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonNegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonNegativeInteger64) -> Self
fn from(f: &NonNegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonNegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonNegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonNegativeInteger8) -> Self
fn from(f: &NonNegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonPositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonPositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonPositiveInteger128) -> Self
fn from(f: &NonPositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonPositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonPositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonPositiveInteger16) -> Self
fn from(f: &NonPositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonPositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonPositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonPositiveInteger32) -> Self
fn from(f: &NonPositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonPositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonPositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonPositiveInteger64) -> Self
fn from(f: &NonPositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonPositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonPositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonPositiveInteger8) -> Self
fn from(f: &NonPositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<i128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<i128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroI128) -> Self
fn from(f: &NonZeroI128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<i16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<i16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroI16) -> Self
fn from(f: &NonZeroI16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<i32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<i32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroI32) -> Self
fn from(f: &NonZeroI32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<i64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<i64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroI64) -> Self
fn from(f: &NonZeroI64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<u128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<u128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroU128) -> Self
fn from(f: &NonZeroU128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<u16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<u16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroU16) -> Self
fn from(f: &NonZeroU16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<u32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<u32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroU32) -> Self
fn from(f: &NonZeroU32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZero<u64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZero<u64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroU64) -> Self
fn from(f: &NonZeroU64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZeroInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZeroInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroInteger128) -> Self
fn from(f: &NonZeroInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZeroInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZeroInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroInteger16) -> Self
fn from(f: &NonZeroInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZeroInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZeroInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroInteger32) -> Self
fn from(f: &NonZeroInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZeroInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZeroInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroInteger64) -> Self
fn from(f: &NonZeroInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&NonZeroInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&NonZeroInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &NonZeroInteger8) -> Self
fn from(f: &NonZeroInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&PositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&PositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &PositiveInteger128) -> Self
fn from(f: &PositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&PositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&PositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &PositiveInteger16) -> Self
fn from(f: &PositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&PositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&PositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &PositiveInteger32) -> Self
fn from(f: &PositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&PositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&PositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &PositiveInteger64) -> Self
fn from(f: &PositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&PositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&PositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &PositiveInteger8) -> Self
fn from(f: &PositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&Prime128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Prime128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Prime16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Prime16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Prime32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Prime32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Prime64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Prime64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&Prime8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&Prime8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&i128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&i128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&i16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&i16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&i32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&i32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&i64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&i64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&i8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&i8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Integer128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Integer128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut Integer128) -> Self
fn from(f: &mut Integer128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut Integer16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Integer16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Integer32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Integer32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Integer64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Integer64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Integer8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Integer8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut NegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NegativeInteger128) -> Self
fn from(f: &mut NegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NegativeInteger16) -> Self
fn from(f: &mut NegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NegativeInteger32) -> Self
fn from(f: &mut NegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NegativeInteger64) -> Self
fn from(f: &mut NegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NegativeInteger8) -> Self
fn from(f: &mut NegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonNegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonNegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonNegativeInteger128) -> Self
fn from(f: &mut NonNegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonNegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonNegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonNegativeInteger16) -> Self
fn from(f: &mut NonNegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonNegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonNegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonNegativeInteger32) -> Self
fn from(f: &mut NonNegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonNegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonNegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonNegativeInteger64) -> Self
fn from(f: &mut NonNegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonNegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonNegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonNegativeInteger8) -> Self
fn from(f: &mut NonNegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonPositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonPositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonPositiveInteger128) -> Self
fn from(f: &mut NonPositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonPositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonPositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonPositiveInteger16) -> Self
fn from(f: &mut NonPositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonPositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonPositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonPositiveInteger32) -> Self
fn from(f: &mut NonPositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonPositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonPositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonPositiveInteger64) -> Self
fn from(f: &mut NonPositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonPositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonPositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonPositiveInteger8) -> Self
fn from(f: &mut NonPositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<i128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<i128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroI128) -> Self
fn from(f: &mut NonZeroI128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<i16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<i16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroI16) -> Self
fn from(f: &mut NonZeroI16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<i32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<i32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroI32) -> Self
fn from(f: &mut NonZeroI32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<i64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<i64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroI64) -> Self
fn from(f: &mut NonZeroI64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<u128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<u128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroU128) -> Self
fn from(f: &mut NonZeroU128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<u16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<u16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroU16) -> Self
fn from(f: &mut NonZeroU16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<u32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<u32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroU32) -> Self
fn from(f: &mut NonZeroU32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZero<u64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZero<u64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroU64) -> Self
fn from(f: &mut NonZeroU64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZeroInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZeroInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroInteger128) -> Self
fn from(f: &mut NonZeroInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZeroInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZeroInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroInteger16) -> Self
fn from(f: &mut NonZeroInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZeroInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZeroInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroInteger32) -> Self
fn from(f: &mut NonZeroInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZeroInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZeroInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroInteger64) -> Self
fn from(f: &mut NonZeroInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut NonZeroInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut NonZeroInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut NonZeroInteger8) -> Self
fn from(f: &mut NonZeroInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut PositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut PositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut PositiveInteger128) -> Self
fn from(f: &mut PositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut PositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut PositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut PositiveInteger16) -> Self
fn from(f: &mut PositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut PositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut PositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut PositiveInteger32) -> Self
fn from(f: &mut PositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut PositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut PositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut PositiveInteger64) -> Self
fn from(f: &mut PositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut PositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut PositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: &mut PositiveInteger8) -> Self
fn from(f: &mut PositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<&mut Prime128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Prime128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Prime16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Prime16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Prime32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Prime32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Prime64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Prime64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut Prime8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut Prime8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut i128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut i128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut i16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut i16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut i32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut i32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut i64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut i64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut i8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut i8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut u128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut u128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut u16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut u16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut u32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut u32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut u64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut u64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&mut u8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&mut u8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&u128> for IntegerBig
Available on crate feature dashu-int only.
impl From<&u128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&u16> for IntegerBig
Available on crate feature dashu-int only.
impl From<&u16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&u32> for IntegerBig
Available on crate feature dashu-int only.
impl From<&u32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&u64> for IntegerBig
Available on crate feature dashu-int only.
impl From<&u64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<&u8> for IntegerBig
Available on crate feature dashu-int only.
impl From<&u8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Integer128> for IntegerBig
Available on crate feature dashu-int only.
impl From<Integer128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: Integer128) -> Self
fn from(f: Integer128) -> Self
Converts to this type from the input type.
Sourceimpl From<Integer16> for IntegerBig
Available on crate feature dashu-int only.
impl From<Integer16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Integer32> for IntegerBig
Available on crate feature dashu-int only.
impl From<Integer32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Integer64> for IntegerBig
Available on crate feature dashu-int only.
impl From<Integer64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Integer8> for IntegerBig
Available on crate feature dashu-int only.
impl From<Integer8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<IntegerBig> for Integers
Available on crate feature dashu-int only.
impl From<IntegerBig> for Integers
Available on crate feature
dashu-int only.Sourcefn from(z: IntegerBig) -> Integers
fn from(z: IntegerBig) -> Integers
Converts to this type from the input type.
Sourceimpl From<NegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<NegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NegativeInteger128) -> Self
fn from(f: NegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<NegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<NegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NegativeInteger16) -> Self
fn from(f: NegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<NegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<NegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NegativeInteger32) -> Self
fn from(f: NegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<NegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<NegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NegativeInteger64) -> Self
fn from(f: NegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<NegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<NegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NegativeInteger8) -> Self
fn from(f: NegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<NonNegativeInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonNegativeInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonNegativeInteger128) -> Self
fn from(f: NonNegativeInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<NonNegativeInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonNegativeInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonNegativeInteger16) -> Self
fn from(f: NonNegativeInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<NonNegativeInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonNegativeInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonNegativeInteger32) -> Self
fn from(f: NonNegativeInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<NonNegativeInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonNegativeInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonNegativeInteger64) -> Self
fn from(f: NonNegativeInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<NonNegativeInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonNegativeInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonNegativeInteger8) -> Self
fn from(f: NonNegativeInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<NonPositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonPositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonPositiveInteger128) -> Self
fn from(f: NonPositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<NonPositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonPositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonPositiveInteger16) -> Self
fn from(f: NonPositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<NonPositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonPositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonPositiveInteger32) -> Self
fn from(f: NonPositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<NonPositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonPositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonPositiveInteger64) -> Self
fn from(f: NonPositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<NonPositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonPositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonPositiveInteger8) -> Self
fn from(f: NonPositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<i128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<i128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroI128) -> Self
fn from(f: NonZeroI128) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<i16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<i16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroI16) -> Self
fn from(f: NonZeroI16) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<i32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<i32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroI32) -> Self
fn from(f: NonZeroI32) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<i64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<i64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroI64) -> Self
fn from(f: NonZeroI64) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<u128>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<u128>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroU128) -> Self
fn from(f: NonZeroU128) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<u16>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<u16>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroU16) -> Self
fn from(f: NonZeroU16) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<u32>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<u32>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroU32) -> Self
fn from(f: NonZeroU32) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZero<u64>> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZero<u64>> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroU64) -> Self
fn from(f: NonZeroU64) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZeroInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZeroInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroInteger128) -> Self
fn from(f: NonZeroInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZeroInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZeroInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroInteger16) -> Self
fn from(f: NonZeroInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZeroInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZeroInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroInteger32) -> Self
fn from(f: NonZeroInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZeroInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZeroInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroInteger64) -> Self
fn from(f: NonZeroInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<NonZeroInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<NonZeroInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: NonZeroInteger8) -> Self
fn from(f: NonZeroInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<PositiveInteger128> for IntegerBig
Available on crate feature dashu-int only.
impl From<PositiveInteger128> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: PositiveInteger128) -> Self
fn from(f: PositiveInteger128) -> Self
Converts to this type from the input type.
Sourceimpl From<PositiveInteger16> for IntegerBig
Available on crate feature dashu-int only.
impl From<PositiveInteger16> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: PositiveInteger16) -> Self
fn from(f: PositiveInteger16) -> Self
Converts to this type from the input type.
Sourceimpl From<PositiveInteger32> for IntegerBig
Available on crate feature dashu-int only.
impl From<PositiveInteger32> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: PositiveInteger32) -> Self
fn from(f: PositiveInteger32) -> Self
Converts to this type from the input type.
Sourceimpl From<PositiveInteger64> for IntegerBig
Available on crate feature dashu-int only.
impl From<PositiveInteger64> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: PositiveInteger64) -> Self
fn from(f: PositiveInteger64) -> Self
Converts to this type from the input type.
Sourceimpl From<PositiveInteger8> for IntegerBig
Available on crate feature dashu-int only.
impl From<PositiveInteger8> for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from(f: PositiveInteger8) -> Self
fn from(f: PositiveInteger8) -> Self
Converts to this type from the input type.
Sourceimpl From<Prime128> for IntegerBig
Available on crate feature dashu-int only.
impl From<Prime128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Prime16> for IntegerBig
Available on crate feature dashu-int only.
impl From<Prime16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Prime32> for IntegerBig
Available on crate feature dashu-int only.
impl From<Prime32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Prime64> for IntegerBig
Available on crate feature dashu-int only.
impl From<Prime64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<Prime8> for IntegerBig
Available on crate feature dashu-int only.
impl From<Prime8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<i128> for IntegerBig
Available on crate feature dashu-int only.
impl From<i128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<i16> for IntegerBig
Available on crate feature dashu-int only.
impl From<i16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<i32> for IntegerBig
Available on crate feature dashu-int only.
impl From<i32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<i64> for IntegerBig
Available on crate feature dashu-int only.
impl From<i64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<i8> for IntegerBig
Available on crate feature dashu-int only.
impl From<i8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<u128> for IntegerBig
Available on crate feature dashu-int only.
impl From<u128> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<u16> for IntegerBig
Available on crate feature dashu-int only.
impl From<u16> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<u32> for IntegerBig
Available on crate feature dashu-int only.
impl From<u32> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<u64> for IntegerBig
Available on crate feature dashu-int only.
impl From<u64> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl From<u8> for IntegerBig
Available on crate feature dashu-int only.
impl From<u8> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl FromStr for IntegerBig
Available on crate feature dashu-int only.
impl FromStr for IntegerBig
Available on crate feature
dashu-int only.Sourcetype Err = NumeraErrors
type Err = NumeraErrors
The associated error which can be returned from parsing.
Sourcefn from_str(s: &str) -> NumeraResult<IntegerBig>
fn from_str(s: &str) -> NumeraResult<IntegerBig>
Parses a string
s to return a value of this type. Read moreSourceimpl Ident for IntegerBig
Available on crate feature dashu-int only.
impl Ident for IntegerBig
Available on crate feature
dashu-int only.Sourcefn can_neg_one(&self) -> bool
fn can_neg_one(&self) -> bool
Returns
true if the number can represent -1,
the additive inverse of the multiplicative identity. Read moreSourcefn is_neg_one(&self) -> bool
fn is_neg_one(&self) -> bool
Returns
true if the current value is -1,
the additive inverse of the multiplicative identity.Sourceimpl Integer for IntegerBig
Available on crate feature dashu-int only.
impl Integer for IntegerBig
Available on crate feature
dashu-int only.Sourcefn integer_is_even(&self) -> bool
fn integer_is_even(&self) -> bool
Returns
true if this integer is even.Sourcefn integer_is_multiple_of(&self, other: &Self) -> bool
fn integer_is_multiple_of(&self, other: &Self) -> bool
Returns
true if this integer is a multiple of the other.Sourcefn integer_is_prime(&self) -> Option<bool>
fn integer_is_prime(&self) -> Option<bool>
Returns
Some(true) if this integer is prime, Some(false) if it’s not
prime, or None if it can not be determined. Read moreSourcefn integer_gcd(&self, other: &Self) -> Option<Self>
fn integer_gcd(&self, other: &Self) -> Option<Self>
Calculates the Greatest Common Divisor of this integer and
other. Read moreSourcefn integer_lcm(&self, other: &Self) -> Option<Self>
fn integer_lcm(&self, other: &Self) -> Option<Self>
Calculates the Lowest Common Multiple of this integer and
other. Read moreSourcefn integer_digits(&self) -> usize
fn integer_digits(&self) -> usize
Returns the number of digits in base 10, without the sign.
Sourcefn integer_is_odd(&self) -> bool
fn integer_is_odd(&self) -> bool
Returns
true if this integer is odd.Sourcefn integer_is_divisor_of(&self, other: &Self) -> bool
fn integer_is_divisor_of(&self, other: &Self) -> bool
Returns
true if this integer is a divisor of the other.Sourceimpl Mul for IntegerBig
Available on crate feature dashu-int only.
impl Mul for IntegerBig
Available on crate feature
dashu-int only.Sourcefn mul(self, rhs: IntegerBig) -> Self::Output
fn mul(self, rhs: IntegerBig) -> Self::Output
Performs the * operation.
Sourcetype Output = IntegerBig
type Output = IntegerBig
The resulting type after applying the
* operator.Sourceimpl MulAssign for IntegerBig
Available on crate feature dashu-int only.
impl MulAssign for IntegerBig
Available on crate feature
dashu-int only.Sourcefn mul_assign(&mut self, rhs: IntegerBig)
fn mul_assign(&mut self, rhs: IntegerBig)
Performs the *= operation.
Sourceimpl Neg for IntegerBig
Available on crate feature dashu-int only.
impl Neg for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl NegOne for IntegerBig
Available on crate feature dashu-int only.
impl NegOne for IntegerBig
Available on crate feature
dashu-int only.Sourcefn new_neg_one() -> Self
fn new_neg_one() -> Self
Returns a new additive inverse of the multiplicative identity,
-1.Sourcefn set_neg_one(&mut self)where
Self: Sized,
fn set_neg_one(&mut self)where
Self: Sized,
Sets this number to
-1.Sourceimpl Number for IntegerBig
Available on crate feature dashu-int only.
impl Number for IntegerBig
Available on crate feature
dashu-int only.Sourcefn from_inner_repr(value: Self::InnerRepr) -> NumeraResult<Self>
fn from_inner_repr(value: Self::InnerRepr) -> NumeraResult<Self>
Sourceunsafe fn from_inner_repr_unchecked(value: Self::InnerRepr) -> Self
Available on crate feature not(safe) only.
unsafe fn from_inner_repr_unchecked(value: Self::InnerRepr) -> Self
not(safe) only.Sourcefn from_innermost_repr(value: Self::InnermostRepr) -> NumeraResult<Self>
fn from_innermost_repr(value: Self::InnermostRepr) -> NumeraResult<Self>
Sourceunsafe fn from_innermost_repr_unchecked(value: Self::InnermostRepr) -> Self
Available on crate feature not(safe) only.
unsafe fn from_innermost_repr_unchecked(value: Self::InnermostRepr) -> Self
not(safe) only.Sourcetype InnermostRepr = IBig
type InnermostRepr = IBig
The innermost primitive representation of the number. Read more
Sourcefn into_inner_repr(self) -> Self::InnerRepr
fn into_inner_repr(self) -> Self::InnerRepr
Deconstructs the number to its inner representation.
Sourcefn into_innermost_repr(self) -> Self::InnermostRepr
fn into_innermost_repr(self) -> Self::InnermostRepr
Deconstructs the number to its innermost representation.
Sourcefn try_from_inner_repr(inner: impl Into<Self::InnerRepr>) -> NumeraResult<Self>where
Self: Sized,
fn try_from_inner_repr(inner: impl Into<Self::InnerRepr>) -> NumeraResult<Self>where
Self: Sized,
Forms a new number from its converted given
inner representation. Read moreSourceimpl One for IntegerBig
Available on crate feature dashu-int only.
impl One for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Ord for IntegerBig
Available on crate feature dashu-int only.
impl Ord for IntegerBig
Available on crate feature
dashu-int only.Sourcefn cmp(&self, other: &IntegerBig) -> Ordering
fn cmp(&self, other: &IntegerBig) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for IntegerBig
Available on crate feature dashu-int only.
impl PartialEq for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl PartialOrd for IntegerBig
Available on crate feature dashu-int only.
impl PartialOrd for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl<'a> Product<&'a IntegerBig> for IntegerBig
Available on crate feature dashu-int only.
impl<'a> Product<&'a IntegerBig> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Product for IntegerBig
Available on crate feature dashu-int only.
impl Product for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Sign for IntegerBig
Available on crate feature dashu-int only.
impl Sign for IntegerBig
Available on crate feature
dashu-int only.Sourcefn can_negative(&self) -> bool
fn can_negative(&self) -> bool
Returns
true if the type can represent negative numbers.Sourcefn can_positive(&self) -> bool
fn can_positive(&self) -> bool
Returns
true if the type can represent positive numbers.Sourcefn is_negative(&self) -> bool
fn is_negative(&self) -> bool
Returns
true if the value is negative (< 0).Sourcefn is_positive(&self) -> bool
fn is_positive(&self) -> bool
Returns
true if the value is positive (> 0).Sourceimpl Sub for IntegerBig
Available on crate feature dashu-int only.
impl Sub for IntegerBig
Available on crate feature
dashu-int only.Sourcefn sub(self, rhs: IntegerBig) -> Self::Output
fn sub(self, rhs: IntegerBig) -> Self::Output
Performs the - operation.
Sourcetype Output = IntegerBig
type Output = IntegerBig
The resulting type after applying the
- operator.Sourceimpl SubAssign for IntegerBig
Available on crate feature dashu-int only.
impl SubAssign for IntegerBig
Available on crate feature
dashu-int only.Sourcefn sub_assign(&mut self, rhs: IntegerBig)
fn sub_assign(&mut self, rhs: IntegerBig)
Performs the -= operation.
Sourceimpl<'a> Sum<&'a IntegerBig> for IntegerBig
Available on crate feature dashu-int only.
impl<'a> Sum<&'a IntegerBig> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Sum for IntegerBig
Available on crate feature dashu-int only.
impl Sum for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl TryFrom<Integers> for IntegerBig
Available on crate feature dashu-int only.
impl TryFrom<Integers> for IntegerBig
Available on crate feature
dashu-int only.Sourceimpl Zero for IntegerBig
Available on crate feature dashu-int only.
impl Zero for IntegerBig
Available on crate feature
dashu-int only.impl Eq for IntegerBig
Available on crate feature
dashu-int only.impl Negative for IntegerBig
Available on crate feature
dashu-int only.impl NonLowerBounded for IntegerBig
Available on crate feature
dashu-int only.impl NonUpperBounded for IntegerBig
Available on crate feature
dashu-int only.impl Positive for IntegerBig
Available on crate feature
dashu-int only.impl StructuralPartialEq for IntegerBig
Available on crate feature
dashu-int only.Auto Trait Implementations
impl Freeze for IntegerBig
impl RefUnwindSafe for IntegerBig
impl Send for IntegerBig
impl Sync for IntegerBig
impl Unpin for IntegerBig
impl UnwindSafe for IntegerBig