pub struct NonZeroInteger128(pub NonZeroI128);Expand description
A 128-bit non-zero integer number, from the set $\Z \setminus 0$,
also known as N0z128.
The range of valid numeric values is $\lbrack$i128::MIN $\dots -1, 1 \dots$ i128::MAX$\rbrack$.
It is equivalent to the NonZeroI128 primitive.
Tuple Fields
0: NonZeroI128Implementations
Sourceimpl NonZeroInteger128
Methods for all integers
impl NonZeroInteger128
Methods for all integers
Sourcepub const fn is_multiple_of(&self, other: &Self) -> bool
pub const fn is_multiple_of(&self, other: &Self) -> bool
Returns true if this integer is a multiple of the other.
Sourcepub const fn is_divisor_of(&self, other: &Self) -> bool
pub const fn is_divisor_of(&self, other: &Self) -> bool
Returns true if this integer is a divisor of the other.
Sourcepub const fn is_coprime(&self, other: &Self) -> bool
pub const fn is_coprime(&self, other: &Self) -> bool
Returns true if self and other are relative primes,
which means they have only 1 as their only common divisor.
Notation
$a \perp b$.
Sourceimpl NonZeroInteger128
Methods for non-negative integers
impl NonZeroInteger128
Methods for non-negative integers
Sourceimpl NonZeroInteger128
Integer addition
impl NonZeroInteger128
Integer addition
Sourcepub const fn basic_add(self, rhs: NonZeroInteger128) -> NonZeroInteger128
pub const fn basic_add(self, rhs: NonZeroInteger128) -> NonZeroInteger128
Sourcepub const fn checked_add(
self,
rhs: NonZeroInteger128,
) -> Option<NonZeroInteger128>
pub const fn checked_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>
Checked addition.
Returns None if the result is 0, or it overflows.
Sourcepub const fn checked_saturating_add(
self,
rhs: NonZeroInteger128,
) -> Option<NonZeroInteger128>
pub const fn checked_saturating_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>
Saturating addition.
Computes self + rhs, saturating at the numeric bounds instead of overflowing.
Panics
If the addition results in 0.
Sourcepub const fn checked_wrapping_add(
self,
rhs: NonZeroInteger128,
) -> Option<NonZeroInteger128>
pub const fn checked_wrapping_add( self, rhs: NonZeroInteger128, ) -> Option<NonZeroInteger128>
Wrapping (modular) addition.
Computes self + rhs, wrapping around at the boundary of the type.
Sourcepub const fn overflowing_add(
self,
rhs: NonZeroInteger128,
) -> (Option<NonZeroInteger128>, bool)
pub const fn overflowing_add( self, rhs: NonZeroInteger128, ) -> (Option<NonZeroInteger128>, bool)
Overflowing addition.
Returns a tuple of the addition along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourceimpl NonZeroInteger128
impl NonZeroInteger128
Sourcepub const fn new(value: i128) -> NumeraResult<Self>
pub const fn new(value: i128) -> NumeraResult<Self>
Sourcepub const unsafe fn new_unchecked(value: i128) -> Self
Available on crate feature not(safe) only.
pub const unsafe fn new_unchecked(value: i128) -> Self
not(safe) only.Sourceimpl NonZeroInteger128
Methods for resizing
impl NonZeroInteger128
Methods for resizing
Sourcepub fn as_larger_or_same(&self) -> NonZeroInteger128
pub fn as_larger_or_same(&self) -> NonZeroInteger128
Returns the current number as the next larger bit-size, or the same if there’s no larger one available.
Sourcepub fn try_as_larger(&self) -> NumeraResult<NonZeroInteger128>
pub fn try_as_larger(&self) -> NumeraResult<NonZeroInteger128>
Tries to return the current number as the next larger bit-size.
Errors
If there’s no larger bit-size available.
Sourcepub fn as_smaller_or_same(&self) -> NonZeroIntegers
Available on crate feature try_from only.
pub fn as_smaller_or_same(&self) -> NonZeroIntegers
try_from only.Returns the current number as the next smaller bit-size, or the same if the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.
Sourcepub fn try_as_smaller(&self) -> NumeraResult<NonZeroInteger64>
Available on crate feature try_from only.
pub fn try_as_smaller(&self) -> NumeraResult<NonZeroInteger64>
try_from only.Tries to return the current number as the next smaller bit-size.
Errors
If the value can’t fit in the smaller bit-size, or if there’s no smaller bit-size available.