pub struct DecFloat128(pub Bitstring128);Available on crate feature
decstr only.Expand description
A 128-bit ieee-754 quadruple-precision decimal floating-point (w) number, from the set $\R$,
also known as Df128.
The range of valid numeric values is $\lbrack$MIN $\dots$ MAX$\rbrack$.
Supports 34 decimal digits of significand and a normalized exponent range of −6176 to +6111.
It doesn’t implement any arithmetic operations and is mainly intended for storage and interchange.
Tuple Fields
0: Bitstring128Implementations
Sourceimpl DecFloat128
Constructors
impl DecFloat128
Constructors
Sourcepub const fn new(value: Bitstring128) -> Self
pub const fn new(value: Bitstring128) -> Self
Returns a new DecFloat128.